#[non_exhaustive]pub struct ProgramSetValidationFailureBuilder { /* private fields */ }Expand description
A builder for ProgramSetValidationFailure.
Implementations
Sourceimpl ProgramSetValidationFailureBuilder
impl ProgramSetValidationFailureBuilder
Sourcepub fn program_index(self, input: i64) -> Self
pub fn program_index(self, input: i64) -> Self
The index of the program within the program set that failed validation.
This field is required.Sourcepub fn set_program_index(self, input: Option<i64>) -> Self
pub fn set_program_index(self, input: Option<i64>) -> Self
The index of the program within the program set that failed validation.
Sourcepub fn get_program_index(&self) -> &Option<i64>
pub fn get_program_index(&self) -> &Option<i64>
The index of the program within the program set that failed validation.
Sourcepub fn inputs_index(self, input: i64) -> Self
pub fn inputs_index(self, input: i64) -> Self
The index of the input within the program set that failed validation.
Sourcepub fn set_inputs_index(self, input: Option<i64>) -> Self
pub fn set_inputs_index(self, input: Option<i64>) -> Self
The index of the input within the program set that failed validation.
Sourcepub fn get_inputs_index(&self) -> &Option<i64>
pub fn get_inputs_index(&self) -> &Option<i64>
The index of the input within the program set that failed validation.
Sourcepub fn errors(self, input: impl Into<String>) -> Self
pub fn errors(self, input: impl Into<String>) -> Self
Appends an item to errors.
To override the contents of this collection use set_errors.
A list of error messages describing the validation failures that occurred.
Sourcepub fn set_errors(self, input: Option<Vec<String>>) -> Self
pub fn set_errors(self, input: Option<Vec<String>>) -> Self
A list of error messages describing the validation failures that occurred.
Sourcepub fn get_errors(&self) -> &Option<Vec<String>>
pub fn get_errors(&self) -> &Option<Vec<String>>
A list of error messages describing the validation failures that occurred.
Sourcepub fn build(self) -> Result<ProgramSetValidationFailure, BuildError>
pub fn build(self) -> Result<ProgramSetValidationFailure, BuildError>
Consumes the builder and constructs a ProgramSetValidationFailure.
This method will fail if any of the following fields are not set: