#[non_exhaustive]pub struct JobCheckpointConfig {
pub local_path: Option<String>,
pub s3_uri: String,
}Expand description
Contains information about the output locations for hybrid job checkpoint data.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.local_path: Option<String>(Optional) The local directory where checkpoint data is stored. The default directory is /opt/braket/checkpoints/.
s3_uri: StringIdentifies the S3 path where you want Amazon Braket to store checkpoint data. For example, s3://bucket-name/key-name-prefix.
Implementations
Sourceimpl JobCheckpointConfig
impl JobCheckpointConfig
Sourcepub fn local_path(&self) -> Option<&str>
pub fn local_path(&self) -> Option<&str>
(Optional) The local directory where checkpoint data is stored. The default directory is /opt/braket/checkpoints/.
Sourceimpl JobCheckpointConfig
impl JobCheckpointConfig
Sourcepub fn builder() -> JobCheckpointConfigBuilder
pub fn builder() -> JobCheckpointConfigBuilder
Creates a new builder-style object to manufacture JobCheckpointConfig.