#[non_exhaustive]pub struct ProgramSetValidationFailure {
pub program_index: i64,
pub inputs_index: Option<i64>,
pub errors: Option<Vec<String>>,
}Expand description
Contains information about validation failures that occurred during the processing of a program set in a quantum task.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.program_index: i64The index of the program within the program set that failed validation.
inputs_index: Option<i64>The index of the input within the program set that failed validation.
errors: Option<Vec<String>>A list of error messages describing the validation failures that occurred.
Implementations
Sourceimpl ProgramSetValidationFailure
impl ProgramSetValidationFailure
Sourcepub fn program_index(&self) -> i64
pub fn program_index(&self) -> i64
The index of the program within the program set that failed validation.
Sourcepub fn inputs_index(&self) -> Option<i64>
pub fn inputs_index(&self) -> Option<i64>
The index of the input within the program set that failed validation.
Sourceimpl ProgramSetValidationFailure
impl ProgramSetValidationFailure
Sourcepub fn builder() -> ProgramSetValidationFailureBuilder
pub fn builder() -> ProgramSetValidationFailureBuilder
Creates a new builder-style object to manufacture ProgramSetValidationFailure.